@@ -1,34 +1,21 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright     1999-2006  David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 1999-2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSERVICE_H
 #define KSERVICE_H
 
 #include "kserviceaction.h"
-#include <QtCore/QStringList>
-#include <QtCore/QVariant>
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
+#include <QStringList>
+#include <QVariant>
+#include <KPluginFactory>
+#include <KPluginLoader>
 #include <ksycocaentry.h>
-#include <QtCore/QCoreApplication>
-#include <QJsonObject>
+#include <QCoreApplication>
 
 class KServiceType;
 class QDataStream;
@@ -41,12 +28,12 @@ class KServicePrivate;
  * @class KService kservice.h <KService>
  *
  * Represent a service, like an application or plugin
- * bound to one or several mimetypes (or servicetypes) as written
+ * bound to one or several MIME types (or servicetypes) as written
  * in its desktop entry file.
  *
  * The starting point you need is often the static methods, like createInstance().
  * The types of service a plugin provides is taken from the accompanying desktop file
- * where the 'ServiceTypes=' field is used.
+ * where the 'X-KDE-ServiceTypes=' field is used.
  *
  * For a tutorial on how to build a plugin-loading mechanism and how to write plugins
  * in general, see http://techbase.kde.org/Development/Tutorials#Services:_Applications_and_Plugins
@@ -58,7 +45,13 @@ class KServicePrivate;
 class KSERVICE_EXPORT KService : public KSycocaEntry
 {
 public:
+    /**
+     * A shared data pointer for KService.
+     */
     typedef QExplicitlySharedDataPointer<KService> Ptr;
+    /**
+     * A list of shared data pointers for KService.
+     */
     typedef QList<Ptr> List;
 
     /**
@@ -83,6 +76,8 @@ public:
      */
     explicit KService(const KDesktopFile *config, const QString &entryPath = QString());
 
+    KService(const KService &other);
+
     virtual ~KService();
 
     /**
@@ -171,11 +166,11 @@ public:
     QString storageId() const;
 
     /**
-     * Describes the DBUS Startup type of the service.
-     * @li None - This service has no DBUS support
-     * @li Unique - This service provides a unique DBUS service.
+     * Describes the D-Bus Startup type of the service.
+     * @li None - This service has no D-Bus support
+     * @li Unique - This service provides a unique D-Bus service.
      *              The service name is equal to the desktopEntryName.
-     * @li Multi - This service provides a DBUS service which can be run
+     * @li Multi - This service provides a D-Bus service which can be run
      *             with multiple instances in parallel. The service name of
      *             an instance is equal to the desktopEntryName + "-" +
      *             the PID of the process.
@@ -188,12 +183,22 @@ public:
      */
     DBusStartupType dbusStartupType() const;
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 63)
     /**
-     * Returns the working directory to run the program in.
      * @return the working directory to run the program in,
      *         or QString() if not set
+     * @deprecated since 5.63, use workingDirectory() instead
      */
+    KSERVICE_DEPRECATED_VERSION(5, 63, "Use KService::workingDirectory()")
     QString path() const;
+#endif
+
+    /**
+     * @return the working directory to run the program in,
+     *         or QString() if not set
+     * @since 5.63
+     */
+    QString workingDirectory() const;
 
     /**
      * Returns the descriptive comment for the service, if there is one.
@@ -232,9 +237,9 @@ public:
     QStringList categories() const;
 
     /**
-     * Returns the list of mime types that this service supports.
-     * Note that this doesn't include inherited mimetypes,
-     * only the mimetypes types listed in the .desktop file.
+     * Returns the list of MIME types that this service supports.
+     * Note that this doesn't include inherited MIME types,
+     * only the MIME types types listed in the .desktop file.
      * @since 4.8.3
      */
     QStringList mimeTypes() const;
@@ -242,7 +247,7 @@ public:
     /**
      * Returns the service types that this service supports.
      * @return the list of service types that are supported
-     * Note that this doesn't include inherited servicetypes or mimetypes,
+     * Note that this doesn't include inherited servicetypes or MIME types,
      * only the service types listed in the .desktop file.
      */
     QStringList serviceTypes() const;
@@ -257,13 +262,14 @@ public:
     bool hasServiceType(const QString &serviceTypePtr) const;
 
     /**
-     * Checks whether the service supports this mime type
-     * @param mimeType The name of the mime type you are
+     * Checks whether the service supports this MIME type
+     * @param mimeType The name of the MIME type you are
      *        interested in determining whether this service supports.
      * @since 4.6
      */
     bool hasMimeType(const QString &mimeType) const;
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 67)
     /**
      * Set to true if it is allowed to use this service as the default (main)
      * action for the files it supports (e.g. Left Click in a file manager, or KRun in general).
@@ -273,8 +279,11 @@ public:
      * Note that servicemenus supersede this functionality though, at least in konqueror.
      *
      * @return true if the service may be used as the default (main) handler
+     * @deprecated since 5.67 due to no known use case
      */
+    KSERVICE_DEPRECATED_VERSION(5, 67, "No known use case")
     bool allowAsDefault() const;
+#endif
 
     /**
      * Returns the actions defined in this desktop file
@@ -306,6 +315,7 @@ public:
      */
     bool noDisplay() const;
 
+#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Whether the service should be shown in KDE at all
      * (including in context menus).
@@ -317,8 +327,8 @@ public:
      * @since 4.5
      * @deprecated since 5.0, use showInCurrentDesktop()
      */
-#ifndef KSERVICE_NO_DEPRECATED
-    KSERVICE_DEPRECATED bool showInKDE() const { return showInCurrentDesktop(); }
+    KSERVICE_DEPRECATED_VERSION(5, 0, "Use KService::showInCurrentDesktop()")
+    bool showInKDE() const { return showInCurrentDesktop(); }
 #endif
 
     /**
@@ -326,7 +336,7 @@ public:
      * (including in context menus).
      * @return true if the service should be shown.
      *
-     * KMimeTypeTrader honors this and removes such services
+     * KApplicationTrader honors this and removes such services
      * from its results.
      *
      * @since 5.0
@@ -351,8 +361,8 @@ public:
 
     /**
      * The keyword to be used when constructing the plugin using KPluginFactory. The keyword is
-     * defined with X-KDE-PluginKeyword in the .desktop file and with K_REGISTER_PLUGIN_WITH_KEYWORD
-     * when implementing the plugin.
+     * defined with X-KDE-PluginKeyword in the .desktop file and with registerPlugin<T>(keyword)
+     * in the K_PLUGIN_FACTORY macro when implementing the plugin.
      */
     QString pluginKeyword() const;
 
@@ -412,12 +422,27 @@ public:
      */
     void setExec(const QString &exec);
 
+    /**
+     * Overrides the "Path=" line of the service.
+     *
+     * If @ref workingDir is not empty, its value will override the one
+     * the one set when this service was created.
+     *
+     * Please note that @ref entryPath is also cleared so the service
+     * will no longer be associated with a specific config file.
+     *
+     * @internal
+     * @param workingDir
+     * @since 5.79
+     */
+    void setWorkingDirectory(const QString &workingDir);
+
     /**
      * Find a service based on its path as returned by entryPath().
      * It's usually better to use serviceByStorageId() instead.
      *
      * @param _path the path of the configuration file
-     * @return a pointer to the requested service or 0 if the service is
+     * @return a pointer to the requested service or @c nullptr if the service is
      *         unknown.
      * @em Very @em important: Don't store the result in a KService* !
      */
@@ -433,7 +458,7 @@ public:
      * but note that it assumes that no two entries have the same filename.
      *
      * @param _name the name of the configuration file
-     * @return a pointer to the requested service or 0 if the service is
+     * @return a pointer to the requested service or @c nullptr if the service is
      *         unknown.
      * @em Very @em important: Don't store the result in a KService* !
      */
@@ -443,7 +468,7 @@ public:
      * Find a service by its menu-id
      *
      * @param _menuId the menu id of the service
-     * @return a pointer to the requested service or 0 if the service is
+     * @return a pointer to the requested service or @c nullptr if the service is
      *         unknown.
      * @em Very @em important: Don't store the result in a KService* !
      */
@@ -454,7 +479,7 @@ public:
      * function will try very hard to find a matching service.
      *
      * @param _storageId the storage id or desktop-file path of the service
-     * @return a pointer to the requested service or 0 if the service is
+     * @return a pointer to the requested service or @c nullptr if the service is
      *         unknown.
      * @em Very @em important: Don't store the result in a KService* !
      */
@@ -477,8 +502,9 @@ public:
      * @param showInMenu true, if the service should be shown in the KDE menu
      *        false, if the service should be hidden from the menu
      *        This argument isn't used anymore, use NoDisplay=true to hide the service.
-     * @param suggestedName name to base the file on, if a service with such
-     *        name already exists, a prefix will be added to make it unique.
+     * @param suggestedName name to base the file on, if a service with such a
+     *        name already exists, a suffix will be added to make it unique
+     *        (e.g. foo.desktop, foo-1.desktop, foo-2.desktop).
      * @param menuId If provided, menuId will be set to the menu id to use for
      *        the KService
      * @param reservedMenuIds If provided, the path and menu id will be chosen
@@ -497,7 +523,7 @@ public:
      * @param parent The parent object (see QObject constructor)
      * @param args A list of arguments, passed to the factory and possibly
      *             to the component (see KPluginFactory)
-     * @param error A pointer to QString which should receive the error description or 0
+     * @param error A pointer to QString which should receive the error description or @c nullptr
      *
      * @return A pointer to the newly created object or a null pointer if the
      *         factory was unable to create an object of the given type.
@@ -506,7 +532,7 @@ public:
     T *createInstance(QObject *parent = nullptr,
                       const QVariantList &args = QVariantList(), QString *error = nullptr) const
     {
-        return createInstance<T>(0, parent, args, error);
+        return createInstance<T>(nullptr, parent, args, error);
     }
 
     /**
@@ -517,7 +543,7 @@ public:
      * @param parent The parent object (see QObject constructor)
      * @param args A list of arguments, passed to the factory and possibly
      *             to the component (see KPluginFactory)
-     * @param error A pointer to QString which should receive the error description or 0
+     * @param error A pointer to QString which should receive the error description or @c nullptr
      *
      * @return A pointer to the newly created object or a null pointer if the
      *         factory was unable to create an object of the given type.
@@ -540,7 +566,7 @@ public:
             *error = pluginLoader.errorString();
             pluginLoader.unload();
         }
-        return 0;
+        return nullptr;
     }
 
     /**
@@ -566,7 +592,7 @@ private:
         ServiceTypeAndPreference(int pref, const QString &servType)
             : preference(pref), serviceType(servType) {}
         int preference;
-        QString serviceType; // or mimetype
+        QString serviceType; // or MIME type
     };
     /// @internal for KBuildSycoca only
     QVector<ServiceTypeAndPreference> &_k_accessServiceTypes();
@@ -574,8 +600,6 @@ private:
     friend QDataStream &operator>>(QDataStream &, ServiceTypeAndPreference &);
     friend QDataStream &operator<<(QDataStream &, const ServiceTypeAndPreference &);
 
-    Q_DISABLE_COPY(KService)
-
     Q_DECLARE_PRIVATE(KService)
 
     friend class KServiceFactory;
